@@ -1,5 +1,5 @@
 package AozoraBunko::Tools::Checkerkun;
-our $VERSION = "0.05";
+our $VERSION = "0.06";
 
 use 5.008001;
 use strict;
@@ -402,7 +402,7 @@ L<包摂 (文字コード) - Wikipedia|https://ja.wikipedia.org/wiki/%E5%8C%85%E
 
 L<JIS漢字で包摂の扱いが変わる文字（[78] [jyogai] など）|http://www.aozora.gr.jp/newJIS-Kanji/gokan_henkou_list.html>
 
-L<Embedding custom non-visible data-* with the data attributes|http://www.w3.org/TR/html5/dom.html#embedding-custom-non-visible-data-with-the-data-*-attributes>
+L<Embedding custom non-visible data with the data-* attributes|http://www.w3.org/TR/html5/dom.html#embedding-custom-non-visible-data-with-the-data-*-attributes>
 
 =head1 LICENSE
 
